@@ -4,7 +4,7 @@ import sys
 from datetime import datetime
 
 from sentry_sdk._compat import reraise
-from sentry_sdk._types import MYPY
+from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk import Hub
 from sentry_sdk.consts import OP
 from sentry_sdk.hub import _should_send_default_pii
@@ -16,7 +16,7 @@ from sentry_sdk.utils import (
     SENSITIVE_DATA_SUBSTITUTE,
 )
 
-if MYPY:
+if TYPE_CHECKING:
     from typing import Any, Callable, Optional, Union, TypeVar
 
     from sentry_sdk._types import EventProcessor, Event, Hint
